@@ -5,17 +5,21 @@
 ## To receive a copy of the licensing terms please write to contact@optumi.com or visit us at https://www.optumi.com.
 ##
 
+from .CloudFileVersion import CloudFileVersion
+
 import optumi_core as optumi
 from optumi_core.exceptions import OptumiException
 
 import os, datetime
 from uuid import uuid4
 
+from typing import List
+
 
 class CloudFile:
     """A class for managing individual files in Optumi cloud storage."""
 
-    def __init__(self, path: str, versions: list):
+    def __init__(self, path: str, versions: List[CloudFileVersion]):
         """Constructor for CloudFile object that describes one file with one or more versions in Optumi cloud storage.
 
         Args:
@@ -35,7 +39,7 @@ class CloudFile:
             if v.path != path:
                 raise OptumiException("CloudFile has inconsistent versions")
 
-    def download(self, wait=True):
+    def download(self, wait: bool = True):
         """Download the newest version of the file in Optumi cloud storage.
 
         Args:
