@@ -12,11 +12,12 @@ from .Server import Server
 from .Resource import Resource
 from .Workload import Workload
 from .EnvironmentVariables import EnvironmentVariables
+from .Notifications import Notifications
 
 import optumi_core as optumi
 
 import os, datetime, json
-from typing import Union
+from typing import Union, List
 
 
 class Colab:
@@ -25,76 +26,18 @@ class Colab:
 
     def launch(
         self,
-        wait=True,
-        progress="summary",
-        packages=Packages(),
-        files=LocalStorage(),
-        env: Union[EnvironmentVariables, list] = [],
-        resource=None,
-        notifications=None,
+        wait: bool = True,
+        progress: str = "summary",
+        packages: Packages = Packages(),
+        files: LocalStorage = LocalStorage(),
+        env: Union[EnvironmentVariables, List[EnvironmentVariables]] = [],
+        resource: Resource = None,
+        notifications: Notifications = None,
     ):
-        if resource is None:
-            resource = Server(size="Standard_NC4as_T4_v3")
-
         if progress != None and not progress in Workload.progress:
             raise OptumiException("Unexpected progress '" + progress + "', expected one of " + str(Workload.progress))
 
-        # Start with blank config
-        nb_config = create_config()
-
-        # Plug in program type
-        nb_config["programType"] = "python notebook"
-
-        # Plug in packages
-        nb_config["upload"]["requirements"] = "\n".join(packages)
-
-        # Plug in files
-        expanded = [f.path for f in files]
-
-        # Make sure files are uploaded
-        files.upload()
-        nb_config["upload"]["files"] = [{"path": optumi.utils.replace_home_with_tilde(path), "enabled": True} for path in expanded]
-
-        # Plug in environment variables
-        if type(env) is EnvironmentVariables:
-            nb_config["integrations"] = [
-                {
-                    "name": env.name,
-                    "enabled": True,
-                    "integrationType": "environment variable",
-                }
-            ]
-        else:
-            nb_config["integrations"] = [
-                {
-                    "name": e.name,
-                    "enabled": True,
-                    "integrationType": "environment variable",
-                }
-                for e in env
-            ]
-
-        # Plug in resource requirements
-        if type(resource) is Server:
-            nb_config["machineAssortment"] = [resource.provider + ":" + resource.size]
-        elif type(resource) is Resource:
-            nb_config["machineAssortment"] = []
-            if type(resource.gpu) is bool:
-                nb_config["graphics"]["cores"] = [1 if resource.gpu else -1, -1, -1]
-            elif type(resource.gpu) is str:
-                nb_config["graphics"]["cores"] = [1, -1, -1]
-                nb_config["graphics"]["boardType"] = resource.gpu
-
-            nb_config["graphics"]["memoryPerCard"] = resource.memory_per_card
-
-        # Plug in requirements
-        if notifications != None:
-            nb_config["notifications"] = {
-                "jobStartedSMSEnabled": notifications.job_started,
-                "jobCompletedSMSEnabled": notifications.job_completed,
-                "jobFailedSMSEnabled": notifications.job_failed,
-                "packageReadySMSEnabled": False,
-            }
+        nb_config = create_config(program_type="python notebook", packages=packages, files=files, env=env, resource=resource, notifications=notifications)
 
         from google.colab import _message
 
@@ -130,22 +73,28 @@ class Colab:
         optumi.core.push_workload_initializing_update(workload_uuid, "Initializing")
         optumi.core.push_workload_initializing_update(workload_uuid, "stop")
 
+        expanded = [f.path for f in files]
+
         hashes = [optumi.utils.hash_file(f) for f in expanded]
         stats = [os.stat(f) if os.path.isfile(f) else None for f in expanded]
         creation_times = [datetime.datetime.utcfromtimestamp(stat.st_ctime).isoformat() + "Z" if stat != None else None for stat in stats]
         last_modification_times = [datetime.datetime.utcfromtimestamp(stat.st_mtime).isoformat() + "Z" if stat != None else None for stat in stats]
         sizes = [str(stat.st_size) if stat else None for stat in stats]
 
-        optumi.core.launch_notebook(
-            nb_config["upload"]["requirements"],
-            hashes,
-            [optumi.utils.replace_home_with_tilde(path) for path in expanded],
-            creation_times,
-            last_modification_times,
-            sizes,
-            workload_uuid,
-            self.__utcnow(),
-        )
+        try:
+            optumi.core.launch_notebook(
+                nb_config["upload"]["requirements"],
+                hashes,
+                [optumi.utils.replace_home_with_tilde(path) for path in expanded],
+                creation_times,
+                last_modification_times,
+                sizes,
+                workload_uuid,
+                self.__utcnow(),
+            )
+        except Exception as err:
+            # Surppress this error so we can poll for the proper status message
+            pass
 
         launch_status = optumi.get_launch_status(workload_uuid)
 
