@@ -35,7 +35,7 @@ class LocalFile:
         """
         self._path = optumi.utils.normalize_path(path)
 
-    def upload(self, wait=True):
+    def upload(self, wait: bool = True):
         """Upload a local file to Optumi cloud storage.
 
         Args:
