@@ -6,7 +6,7 @@
 ##
 
 import os
-from .utils import *
+from .utils import fixBackspace, fixCarriageReturn
 
 import optumi_core as optumi
 
