@@ -77,7 +77,7 @@ class Machine:
                         self._state,
                     ) = Machine.reconstruct(machine)
 
-    def release(self, override=False):
+    def release(self, override: bool = False):
         """Release the dynamically allocated machine.
 
         Args:
