@@ -5,7 +5,7 @@
 ## To receive a copy of the licensing terms please write to contact@optumi.com or visit us at https://www.optumi.com.
 ##
 
-from .Executable import *
+from .Executable import Executable
 
 
 class Script(Executable):
