@@ -14,11 +14,13 @@ from .Log import Log
 from .Summary import Summary
 from .Program import Program
 from .Machine import Machine
-from .utils import *
+from .utils import collapseUpdates
 
 import json, time, os, re
 from sys import exit
 
+from typing import List, Tuple
+
 
 class Workload:
     """A class representing an individual workload.
@@ -29,15 +31,15 @@ class Workload:
     status_values = ["queued", "launching", "running", "completed"]
     progress = ["silent", "summary", "detail"]  # add "status" later
 
-    def __init__(self, path, program, workload_uuid, module_uuid, config, run_num):
+    def __init__(self, path: str, program: str, workload_uuid: str, module_uuid: str, config: dict, run_num: int):
         """Constructor for a Workload object.
 
         Args:
             path (str): The file path of the workload.
-            program (Program): Program object associated with this workload.
+            program (str): Program content (script, notebook, or container info) associated with this workload.
             workload_uuid (str): Unique identifier for the workload.
             module_uuid (str): Unique identifier for the module.
-            config (dict): Dictionary containing configuration related to this workload.
+            config (dict): Dictionary containing configuration related to this workload. See NotebookConfig for dictionary layout.
             run_num (int): Numerical value corresponding to which run of the given program this workload represents.
         """
         self._path = path
@@ -67,7 +69,7 @@ class Workload:
 
         self._last_refresh = time.time()
 
-    def _handle_workload_update(self, workload):
+    def _handle_workload_update(self, workload: str):
         updates_to_print = []
 
         if "uuid" in workload and workload["uuid"] != None:
@@ -112,7 +114,7 @@ class Workload:
 
         return updates_to_print
 
-    def _handle_module_update(self, module):
+    def _handle_module_update(self, module: str):
         output_to_print = []
 
         if "uuid" in module and module["uuid"] != None:
@@ -202,12 +204,12 @@ class Workload:
     #     print(line, end="", flush=True)
     #     time.sleep(0.3)
 
-    def __print_output(self, progress, output_to_print):
+    def __print_output(self, progress: str, output_to_print: List[Tuple[str, str]]):
         if progress == "detail":
             for output in output_to_print:
                 print(output[0], end="")
 
-    def __print_updates(self, progress, updates_to_print):
+    def __print_updates(self, progress: str, updates_to_print: List[Tuple[str, str]]):
         for update in updates_to_print:
             if re.sub("[^a-zA-Z]", "", update[0]) != "" and update[0] != "\n" and update[0] != "stop" and update[0] != "error":
                 if progress == "summary":
@@ -219,7 +221,7 @@ class Workload:
                 # elif progress == "status":
                 #     self.__print_status()
 
-    def wait(self, progress="summary"):
+    def wait(self, progress: str = "summary"):
         """Wait for a workload to complete by regularly checking the workload status.
 
         Args:
@@ -275,7 +277,7 @@ class Workload:
         # if progress == "status":
         #     print()
 
-    def stop(self, wait=True):
+    def stop(self, wait: bool = True):
         """Stop the current workload.
 
         Args:
@@ -298,7 +300,7 @@ class Workload:
                     self.wait(progress="silent")
             print("...completed")
 
-    def remove(self, wait=True):
+    def remove(self, wait: bool = True):
         """Remove the current workload."""
         if self.status != "completed":
             self.stop(wait)
@@ -345,7 +347,7 @@ class Workload:
 
         return "launching"
 
-    def __adjust_message(self, message):
+    def __adjust_message(self, message: str):
         # We will say a session is starting until we can connect to it
         if self._nb_config["interactive"] and message == "Running" and self._token == None:
             return "Connecting"
@@ -403,7 +405,7 @@ class Workload:
         return message
 
     @classmethod
-    def __is_error(cls, update):
+    def __is_error(cls, update: Tuple[str, str]):
         line = update[0]
         modifier = update[1]
         if line == "error":
@@ -416,15 +418,15 @@ class Workload:
         return False
 
     @classmethod
-    def __is_stop(cls, update):
+    def __is_stop(cls, update: Tuple[str, str]):
         return update[0] == "stop"
 
     @classmethod
-    def __is_terminated(cls, update):
+    def __is_terminated(cls, update: Tuple[str, str]):
         return update[0] == "Terminated"
 
     @classmethod
-    def __message(cls, updates):
+    def __message(cls, updates: List[Tuple[str, str]]):
         for update in reversed(updates):
             line = update[0]
             modifier = update[1]
