@@ -5,16 +5,17 @@
 ## To receive a copy of the licensing terms please write to contact@optumi.com or visit us at https://www.optumi.com.
 ##
 
+from ._version import __version__
+
+
 from .LoginServer import login as oauth_login
 from .HoldoverTime import HoldoverTime
 from .Workloads import Workloads
+
+import datetime, json, os, webbrowser
+import phonenumbers
 from requests.exceptions import ConnectionError
 
-import phonenumbers
-
-# Generic Operating System Services
-import datetime, json, os
-from typing import Union
 
 # Optumi imports
 import optumi_core as optumi
@@ -24,78 +25,30 @@ from optumi_core.exceptions import (
     OptumiException,
 )
 
+from typing import Union
+
 DEBUG_LOGIN = False
 
-# We will keep various lists from the controller in place of enums
-_machines = None
-_providers = None
-_graphics_card_types = None
 
+def docs(open: bool = True):
+    """Print or open the url for full Optumi API documentation.
 
-def machines():
-    """Obtain the inventory of machines available from current cloud providers.
-
-    Returns:
-        list of str: The list of available machines where each element represents a machine provider and machine size, separated by a colon (':').
+    Args:
+        open (bool, optional): Wether to print the url or open the docs in a new browser tab. Defaults to True.
     """
-    if _machines is None:
-        _update_inventory_info()
-    return _machines
+    url = "https://portal.optumi.net/docs"
+    if open:
+        webbrowser.open_new_tab(url)
+    else:
+        print("Optumi API documentation is available at: " + url)
 
 
-def providers():
-    """Obtain the list of current cloud providers.
-
-    Returns:
-        list of str: The list of cloud providers that are currently enabled for dyamic machine allocation.
-    """
-    if _providers is None:
-        _update_inventory_info()
-    return _providers
-
-
-def graphics_card_types():
-    """Obtain the list of current graphics cards.
-
-    Returns:
-        list of str: The list of GPU card types that are currently available in the machine inventory.
-    """
-    if _graphics_card_types is None:
-        _update_inventory_info()
-    return _graphics_card_types
-
-
-def _update_inventory_info():
-    global _machines, _providers, _graphics_card_types
-
-    user_information = json.loads(optumi.core.get_user_information(True).text)
-
-    _machines = []
-    _providers = []
-    _graphics_card_types = []
-
-    for machine in user_information["machines"]:
-        name = machine["name"]
-        provider = name.split(":")[0]
-        graphics_card_type = machine["graphicsCardType"]
-
-        if not machine in _machines:
-            _machines.append(name)
-
-        if not provider in _providers:
-            _providers.append(provider)
-
-        if not graphics_card_type in _graphics_card_types:
-            _graphics_card_types.append(graphics_card_type)
-
-    _machines.sort()
-    _providers.sort()
-    _graphics_card_types.sort()
+docs(False)
 
 
 def login(
-    connection_token=None,
-    save_token=True,
+    connection_token: str = None,
+    save_token: bool = True,
 ):
     """Log in to the Optumi service platform.
 
@@ -109,6 +62,25 @@ def login(
         NotLoggedInException: Raised if the login was not successful.
         OptumiException: Raised if the browser login could not be initiated.
     """
+
+    def handle_login_response(login_status, message):
+        if login_status == -2:  # -3 means we have a version problem
+            split = message.split("-")[0].split(".")
+            downgrade = __version__.split(".")[1] > split[1]
+            compatible_version = ">=" + split[0] + "." + split[1] + ".0,<" + split[0] + "." + str(int(split[1]) + 1) + ".0"
+
+            raise NotLoggedInException(
+                "Sorry, we've noticed an incompatibility between this API version and our backend. To switch to a compatible extension run: pip install \"optumi-api"
+                + compatible_version
+                + '"'
+                if downgrade
+                else "We've made enhancements that require a new API version. To upgrade your extension, run:pip install \"optumi-api"
+                + compatible_version
+                + '"'
+            )
+        if login_status != 1:
+            raise NotLoggedInException("Login failed: " + message)
+
     dnsName = optumi.utils.get_portal()
     port = optumi.utils.get_portal_port()
 
@@ -129,54 +101,49 @@ def login(
     else:
         if DEBUG_LOGIN:
             print("Normal login")
-        if not optumi.login.check_login(dnsName, port):
+        if connection_token == None:
             if DEBUG_LOGIN:
-                print("Not logged in")
-            if connection_token == None:
-                if DEBUG_LOGIN:
-                    print("No connection token")
-                if DEBUG_LOGIN:
-                    print("Trying login with disk token")
-                # Try to log in with the login token from the disk
-                login_status, message = optumi.login.login_rest_server(dnsName, port, login_type="token", save_token=save_token)
+                print("No connection token")
+            if DEBUG_LOGIN:
+                print("Trying login with disk token")
+            # Try to log in with the login token from the disk
+            login_status, message = optumi.login.login_rest_server(dnsName, port, login_type="token", save_token=save_token)
 
-                # Fall back on the browser login
-                if login_status != 1:
-                    if DEBUG_LOGIN:
-                        print("Trying browser login")
-                    try:
-                        login_status, message = optumi.login.login_rest_server(
-                            dnsName,
-                            port,
-                            oauth_login(),
-                            login_type="oauth",
-                            save_token=save_token,
-                        )
-                        if login_status != 1:
-                            raise NotLoggedInException("Login failed: " + message)
-                    except RuntimeError:
-                        raise OptumiException(
-                            "Unable to perform browser login from Notebook. Try logging in with a connection token as shown here: https://optumi.notion.site/Login-using-a-connection-token-710bccdeaf734cbf825aae94b79a8109"
-                        )
-            else:
+            # Fall back on the browser login
+            if login_status != 1:
                 if DEBUG_LOGIN:
-                    print("Connection token")
-                login_status, message = optumi.login.login_rest_server(
-                    dnsName,
-                    port,
-                    connection_token,
-                    login_type="token",
-                    save_token=save_token,
-                )
-                if login_status != 1:
-                    raise NotLoggedInException("Login failed: " + message)
+                    print("Trying browser login")
+                try:
+                    login_status, message = optumi.login.login_rest_server(
+                        dnsName,
+                        port,
+                        oauth_login(),
+                        login_type="oauth",
+                        save_token=save_token,
+                    )
+                    handle_login_response(login_status, message)
+                except RuntimeError:
+                    raise OptumiException(
+                        "Unable to perform browser login from Notebook. Try logging in with a connection token as shown here: https://optumi.notion.site/Login-using-a-connection-token-710bccdeaf734cbf825aae94b79a8109"
+                    )
+        else:
+            if DEBUG_LOGIN:
+                print("Connection token")
+            login_status, message = optumi.login.login_rest_server(
+                dnsName,
+                port,
+                connection_token,
+                login_type="token",
+                save_token=save_token,
+            )
+            handle_login_response(login_status, message)
 
     user_information = json.loads(optumi.core.get_user_information(True).text)
 
     print("Logged in", user_information["name"])
 
 
-def logout(remove_token=True):
+def logout(remove_token: bool = True):
     """Log out of the Optumi service platform, optionally removing any stored connection token.
 
     Args:
@@ -197,7 +164,7 @@ def get_phone_number():
     return json.loads(optumi.core.get_user_information(False).text)["phoneNumber"]
 
 
-def set_phone_number(phone_number):
+def set_phone_number(phone_number: str):
     """Prompt the user for a verification code and store the phone number in the user's profile.
 
     Args:
@@ -249,7 +216,7 @@ def set_holdover_time(holdover_time: Union[int, HoldoverTime]):
     The holdover time is the period of time that machines are retained (provisioned) after a workload finishes. Holdover time is global and applies to all workloads.
 
     Args:
-        holdover_time (Union[int, HoldoverTime]): The holdover time as either an integer representing minutes or a HoldoverTime object.
+        holdover_time (int or HoldoverTime): The holdover time as either an integer representing minutes or a HoldoverTime object.
     """
     optumi.core.set_user_information(
         "userHoldoverTime",
@@ -257,7 +224,7 @@ def set_holdover_time(holdover_time: Union[int, HoldoverTime]):
     )
 
 
-def get_connection_token(forceNew=False):
+def get_connection_token(forceNew: bool = False):
     """Obtain a connection token.
 
     Args:
@@ -269,7 +236,7 @@ def get_connection_token(forceNew=False):
     return json.loads(optumi.core.get_connection_token(forceNew).text)
 
 
-def redeem_signup_code(signupCode):
+def redeem_signup_code(signupCode: str):
     """Redeem a signup code used to obtain access to the Optumi service platform.
 
     Args:
@@ -278,7 +245,7 @@ def redeem_signup_code(signupCode):
     optumi.core.redeem_signup_code(signupCode)
 
 
-def send_notification(message, details=True):
+def send_notification(message: str, details=True):
     """Send a notification via text message to the phone number associated with the current user.
 
     Optionally, additional details about the workload can be attached to the end of the message.
